<?php

namespace Drupal\github_connect\Plugin\Block;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Link;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a 'github_connect' block.
 *
 * @Block(
 *   id = "github_connect_block",
 *   admin_label = @Translation("Github Connect"),
 * )
 */
class GithubConnectBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * Stores the configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected ConfigFactoryInterface $configFactory;

  /**
   * GithubConnectBlock constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   A config factory for retrieving required config objects.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ConfigFactoryInterface $config_factory) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function blockAccess(AccountInterface $account) {
    return $account->isAnonymous() ? AccessResult::allowed() : AccessResult::forbidden();
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    global $base_url;

    $config = $this->configFactory->get('github_connect.settings');
    $client_id = $config->get('client_id');

    $option = [
      'query' => [
        'client_id' => $client_id,
        'scope' => 'user,public',
        'uri' => urlencode($base_url . '/github/register/create'),
      ],
      'attributes' => [
        'class' => [
          'github-link'
        ]
      ]
    ];
    $url = Url::fromUri('https://github.com/login/oauth/authorize', $option);
    $output = Link::fromTextAndUrl($this->t('Login with GitHub'), $url)->toString();
    return [
      '#type' => 'markup',
      '#markup' => $output,
      '#attached' => [
        'library' => ['github_connect/github_connect_icon'],
      ],
    ];

  }

}
